
# Slot: subproperty_of


Ontology property which this slot is a subproperty of

URI: [linkml:subproperty_of](https://w3id.org/linkml/subproperty_of)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [SlotDefinition](SlotDefinition.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | rdfs:subPropertyOf |

